@@ -289,8 +289,7 @@ class FastBERT(nn.Module):
                     break
 
         label_id = torch.argmax(probs, dim=1).item()
-        label = self.id2label[label_id]
-        return label, exec_layer_num
+        return label_id, exec_layer_num
 
     def _forward_for_loss(self,
                           sentences_batch,
@@ -433,7 +432,7 @@ class FastBERT(nn.Module):
                 scheduler.step()
 
             dev_acc, _ = self._evaluate(sentences_dev, labels_dev, speed=0.0) \
-                    if dev_num > 0 else 0.0
+                    if dev_num > 0 else (0.0, 0.0)
             train_acc, _ = self._evaluate(sentences_train, labels_train, speed=0.0)
             if verbose:
                 print("[FastBERT]: Evaluating at fine-tuning epoch {}/{}".\
@@ -544,7 +543,7 @@ class FastBERT(nn.Module):
                 scheduler.step()
 
             dev_acc, ave_layers = self._evaluate(sentences_dev, labels_dev, speed=0.5) \
-                    if dev_num > 0 else 0.0
+                    if dev_num > 0 else (0.0, 0)
             print("[FastBERT]: Evaluating at self-disilling epoch {}/{}".\
                     format(epoch+1, epochs_num),
                     "dev_acc = {:.3f}, ave_exec_layers = {:.3f}".format(dev_acc, ave_layers))
@@ -604,12 +603,12 @@ class FastBERT_S2(FastBERT):
         labels_dev = kwargs.pop('labels_dev', [])
 
         super(FastBERT_S2, self).fit(
-                sentences_train, 
-                labels_train, 
+                sentences_train,
+                labels_train,
                 sentences_dev=sentences_dev,
                 labels_dev=labels_dev,
                 verbose=verbose,
-                **kwargs) 
+                **kwargs)
 
     def forward(self,
                 sent_a,
@@ -626,7 +625,7 @@ class FastBERT_S2(FastBERT):
             label - str/int - the predict label.
             exec_layer_num - int - the number of the executed layers.
         """
-        sent = self.merge(sent_a, sent_b)
+        sent = self._merge(sent_a, sent_b)
         label, exec_layer_num = super(FastBERT_S2, self).forward(sent, speed)
         return label, exec_layer_num
 
